@@ -20,12 +20,12 @@
 #include "config.h"
 #endif
 
-#include "panel/panel-application.h"
-#include "panel/panel-dialogs.h"
-#include "panel/panel-item-dialog.h"
-#include "panel/panel-module-factory.h"
-#include "panel/panel-module.h"
-#include "panel/panel-preferences-dialog.h"
+#include "panel-application.h"
+#include "panel-dialogs.h"
+#include "panel-item-dialog.h"
+#include "panel-module-factory.h"
+#include "panel-module.h"
+#include "panel-preferences-dialog.h"
 
 #include "common/panel-private.h"
 #include "common/panel-utils.h"
